==> haskell-placeholders-0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 placeholders
version:              0.1
visibility:           public
id:                   placeholders-0.1-LDb3Y3WvlFvIYaPJl9Rx4h
key:                  placeholders-0.1-LDb3Y3WvlFvIYaPJl9Rx4h
license:              BSD-3-Clause
copyright:            (c) 2011 Andreas Hammar
maintainer:           Andreas Hammar <ahammar@gmail.com>
author:               Andreas Hammar
homepage:             http://github.com/ahammar/placeholders
synopsis:             Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.

    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>

category:             Development
abi:                  56d89d5865834acb62808e32e271d729
exposed:              True
exposed-modules:      Development.Placeholders
import-dirs:          /usr/lib/ghc-8.8.3/site-local/placeholders-0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/placeholders-0.1
hs-libraries:         HSplaceholders-0.1-LDb3Y3WvlFvIYaPJl9Rx4h
depends:              base-4.13.0.0 template-haskell-2.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-placeholders/html/placeholders.haddock

haddock-html:         /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-placeholders-0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 placeholders
version:              0.1
visibility:           public
id:                   placeholders-0.1-5EZJOo60uJJURzlenu3mo
key:                  placeholders-0.1-5EZJOo60uJJURzlenu3mo
license:              BSD-3-Clause
copyright:            (c) 2011 Andreas Hammar
maintainer:           Andreas Hammar <ahammar@gmail.com>
author:               Andreas Hammar
homepage:             http://github.com/ahammar/placeholders
synopsis:             Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.

    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>

category:             Development
abi:                  06cbb79c0019c59804423a03953508bf
exposed:              True
exposed-modules:      Development.Placeholders
import-dirs:          /usr/lib/ghc-8.10.1/site-local/placeholders-0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/placeholders-0.1
hs-libraries:         HSplaceholders-0.1-5EZJOo60uJJURzlenu3mo
depends:              base-4.14.0.0 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-placeholders/html/placeholders.haddock

haddock-html:         /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
